/* This file contains functions to
 * compute the Landau distribution
 * PDF, CDF and QDF functions.
 */

#pragma once

/* This is a wrapper needed by `landau_cdf` because
 * the numerical integration expects a function
 * with parameters.
 */
double landau_pdf(double x, void* params);


/* The cumulative function of the Landau distribution
 * calculated by numerical integration.
 */
double landau_cdf(double x, void* params);


/* The quantile function (inverse CDF) of the Landau
 * distribution calculated by numerical root method.
 */
double landau_qdf(double p0);
